netapp_ontap.models.oracle_rac_on_nfs API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.oracle_rac_on_nfs`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class OracleRacOnNfsSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the OracleRacOnNfs object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `archive_log: OracleOnNfsArchiveLog GET POST PATCH`

    The archive_log field of the oracle_rac_on_nfs.

  `db: OracleOnNfsDb GET POST PATCH`

    The db field of the oracle_rac_on_nfs.

  `grid_binary: OracleRacOnNfsGridBinary GET POST PATCH`

    The grid_binary field of the oracle_rac_on_nfs.

  `nfs_access: List[AppNfsAccess] GET POST`

    The list of NFS access controls. You must provide either 'host' or 'access' to enable NFS access.

  `ora_home: OracleOnNfsOraHome GET POST PATCH`

    The ora_home field of the oracle_rac_on_nfs.

  `oracle_crs: OracleRacOnNfsOracleCrs GET POST PATCH`

    The oracle_crs field of the oracle_rac_on_nfs.

  `protection_type: MongoDbOnSanProtectionType GET POST PATCH`

    The protection_type field of the oracle_rac_on_nfs.

  `redo_log: OracleOnNfsRedoLog GET POST PATCH`

    The redo_log field of the oracle_rac_on_nfs.